@@ -1,3 +1,4 @@
+# $Id: MapGen.pm,v 1.56 2005/04/05 15:05:21 jettero Exp $
 # vi:tw=0 syntax=perl:
 
 package Games::RolePlay::MapGen;
@@ -7,7 +8,7 @@ use AutoLoader;
 use Carp;
 use Data::Dumper; $Data::Dumper::Indent = 1; $Data::Dumper::SortKeys = 1;
 
-our $VERSION = "0.31.2";
+our $VERSION = "0.26";
 our $AUTOLOAD;
 
 our %opp = (n=>"s", e=>"w", s=>"n", w=>"e");
@@ -17,7 +18,7 @@ our %known_opts = (
     generator              => "Basic",
     exporter               => "Text",
     bounding_box           => "50x50",
-    tile_size              => 10,
+    tile_size              => "10 ft",
     cell_size              => "20x20",
 
     num_rooms              => "1d4+1",
@@ -90,9 +91,6 @@ sub AUTOLOAD {
     my $this = shift;
     my $sub  = $AUTOLOAD;
 
-    # sub set_generator
-    # sub set_exporter
-
     if( $sub =~ m/MapGen\:\:set_(generator|exporter)$/ ) {
         my $type = $1;
         my $modu = shift;
@@ -158,10 +156,10 @@ sub save_map {
 
     my @keys = keys %$this;
 
-    open my $save, ">$filename" or die "couldn't open $filename for write: $!";
-    print $save "#!/usr/bin/perl\n\n";
-    print $save Data::Dumper->Dump([map($this->{$_}, @keys)], [map("\$this\-\>{$_}", @keys)]);
-    close $save;
+    open _SAVE, ">$filename" or die "couldn't open $filename for write: $!";
+    print _SAVE "#!/usr/bin/perl\n\n";
+    print _SAVE Data::Dumper->Dump([map($this->{$_}, @keys)], [map("\$this\-\>{$_}", @keys)]);
+    close _SAVE;
 
     $this->{_the_map}->interconnect_map;
 }
@@ -171,10 +169,9 @@ sub load_map {
     my $this     = shift;
     my $filename = shift;
 
-    open my $load, "$filename" or die "couldn't open $filename for read: $!";
-    local $/ = undef;
-    my $entire_file = <$load>;
-    close $load;
+    open _LOAD, "$filename" or die "couldn't open $filename for read: $!";
+    my $entire_file = join("", <_LOAD>);
+    close _LOAD;
 
     eval $entire_file;
     die "ERROR while evaluating saved map: $@" if $@;
@@ -190,15 +187,8 @@ sub generate {
 
     __MADE_GEN_OBJ:
     if( my $gen = $this->{objs}{generator} ) {
-        my $new_opts;
 
-        ($this->{_the_map}, $this->{_the_groups}, $new_opts) = $gen->go( @_ );
-
-        if( $new_opts and keys %$new_opts ) {
-            for my $k (keys %$new_opts) {
-                $this->{$k} = $new_opts->{$k};
-            }
-        }
+        ($this->{_the_map}, $this->{_the_groups}) = $gen->go( @_ );
 
         return;
 
